#[repr(transparent)]pub struct I32NotAllOnes(i32 is (..=-1 | 0..=));🔬This is a nightly-only experimental API. (
temporary_niche_types)Tuple Fields
0: i32 is (..=-1 | 0..=)🔬This is a nightly-only experimental API. (
temporary_niche_types)Implementations
Sourceimpl I32NotAllOnes
impl I32NotAllOnes
pub const fn new(val: i32) -> Option<Self>
🔬This is a nightly-only experimental API. (
temporary_niche_types)Sourcepub const unsafe fn new_unchecked(val: i32) -> Self
🔬This is a nightly-only experimental API. (temporary_niche_types)
pub const unsafe fn new_unchecked(val: i32) -> Self
temporary_niche_types)Constructs an instance of this type from the underlying integer primitive without checking whether its valid.
Safety
Immediate language UB if val is not within the valid range for this
type, as it violates the validity invariant.
pub const fn as_inner(self) -> i32
🔬This is a nightly-only experimental API. (
temporary_niche_types)Trait Implementations
Sourceimpl Clone for I32NotAllOnes
impl Clone for I32NotAllOnes
Sourcefn clone(&self) -> I32NotAllOnes
fn clone(&self) -> I32NotAllOnes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)where
Self:,
fn clone_from(&mut self, source: &Self)where
Self:,
Performs copy-assignment from
source. Read moreimpl Copy for I32NotAllOnes
Sourceimpl Debug for I32NotAllOnes
impl Debug for I32NotAllOnes
Sourceimpl Eq for I32NotAllOnes
impl Eq for I32NotAllOnes
1.0.0 (const: unstable) · Source#[doc(hidden)]fn assert_receiver_is_total_eq(&self)
#[doc(hidden)]fn assert_receiver_is_total_eq(&self)
👎Deprecated since 1.95.0:
implementation detail of #[derive(Eq)]
Source#[doc(hidden)]fn assert_fields_are_eq(&self)
#[doc(hidden)]fn assert_fields_are_eq(&self)
🔬This is a nightly-only experimental API. (
derive_eq_internals)Sourceimpl Hash for I32NotAllOnes
impl Hash for I32NotAllOnes
Sourceimpl Ord for I32NotAllOnes
impl Ord for I32NotAllOnes
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for I32NotAllOnes
impl PartialEq for I32NotAllOnes
Sourceimpl PartialOrd for I32NotAllOnes
impl PartialOrd for I32NotAllOnes
Sourcefn partial_cmp(&self, other: &Self) -> Option<Ordering>
fn partial_cmp(&self, other: &Self) -> Option<Ordering>
Source#[doc(hidden)]fn __chaining_lt(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_lt(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)If
self == other, returns ControlFlow::Continue(()).
Otherwise, returns ControlFlow::Break(self < other). Read moreSource#[doc(hidden)]fn __chaining_le(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_le(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for <= instead of <.Source#[doc(hidden)]fn __chaining_gt(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_gt(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for > instead of <.Source#[doc(hidden)]fn __chaining_ge(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_ge(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for >= instead of <.impl StructuralPartialEq for I32NotAllOnes
impl TrivialClone for I32NotAllOnes