#[repr(transparent)]pub struct Nanoseconds(u32 is 0..=999999999);🔬This is a nightly-only experimental API. (
temporary_niche_types)Tuple Fields
0: u32 is 0..=999999999🔬This is a nightly-only experimental API. (
temporary_niche_types)Implementations
Sourceimpl Nanoseconds
impl Nanoseconds
pub const fn new(val: u32) -> Option<Self>
🔬This is a nightly-only experimental API. (
temporary_niche_types)Sourcepub const unsafe fn new_unchecked(val: u32) -> Self
🔬This is a nightly-only experimental API. (temporary_niche_types)
pub const unsafe fn new_unchecked(val: u32) -> Self
temporary_niche_types)Constructs an instance of this type from the underlying integer primitive without checking whether its valid.
Safety
Immediate language UB if val is not within the valid range for this
type, as it violates the validity invariant.
pub const fn as_inner(self) -> u32
🔬This is a nightly-only experimental API. (
temporary_niche_types)Sourceimpl Nanoseconds
impl Nanoseconds