#[repr(transparent)]pub struct NonZeroCharInner(char is '\u{1}'..);🔬This is a nightly-only experimental API. (
temporary_niche_types)Tuple Fields
0: char is '\u{1}'..🔬This is a nightly-only experimental API. (
temporary_niche_types)Implementations
Sourceimpl NonZeroCharInner
impl NonZeroCharInner
pub const fn new(val: char) -> Option<Self>
🔬This is a nightly-only experimental API. (
temporary_niche_types)Sourcepub const unsafe fn new_unchecked(val: char) -> Self
🔬This is a nightly-only experimental API. (temporary_niche_types)
pub const unsafe fn new_unchecked(val: char) -> Self
temporary_niche_types)Constructs an instance of this type from the underlying integer primitive without checking whether its valid.
Safety
Immediate language UB if val is not within the valid range for this
type, as it violates the validity invariant.
pub const fn as_inner(self) -> char
🔬This is a nightly-only experimental API. (
temporary_niche_types)Trait Implementations
Sourceimpl Clone for NonZeroCharInner
impl Clone for NonZeroCharInner
Sourcefn clone(&self) -> NonZeroCharInner
fn clone(&self) -> NonZeroCharInner
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)where
Self:,
fn clone_from(&mut self, source: &Self)where
Self:,
Performs copy-assignment from
source. Read moreimpl Copy for NonZeroCharInner
Sourceimpl Debug for NonZeroCharInner
impl Debug for NonZeroCharInner
Sourceimpl Eq for NonZeroCharInner
impl Eq for NonZeroCharInner
1.0.0 (const: unstable) · Source#[doc(hidden)]fn assert_receiver_is_total_eq(&self)
#[doc(hidden)]fn assert_receiver_is_total_eq(&self)
👎Deprecated since 1.95.0:
implementation detail of #[derive(Eq)]
Source#[doc(hidden)]fn assert_fields_are_eq(&self)
#[doc(hidden)]fn assert_fields_are_eq(&self)
🔬This is a nightly-only experimental API. (
derive_eq_internals)Sourceimpl Hash for NonZeroCharInner
impl Hash for NonZeroCharInner
Sourceimpl Ord for NonZeroCharInner
impl Ord for NonZeroCharInner
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NonZeroCharInner
impl PartialEq for NonZeroCharInner
Sourceimpl PartialOrd for NonZeroCharInner
impl PartialOrd for NonZeroCharInner
Sourcefn partial_cmp(&self, other: &Self) -> Option<Ordering>
fn partial_cmp(&self, other: &Self) -> Option<Ordering>
Source#[doc(hidden)]fn __chaining_lt(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_lt(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)If
self == other, returns ControlFlow::Continue(()).
Otherwise, returns ControlFlow::Break(self < other). Read moreSource#[doc(hidden)]fn __chaining_le(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_le(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for <= instead of <.Source#[doc(hidden)]fn __chaining_gt(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_gt(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for > instead of <.Source#[doc(hidden)]fn __chaining_ge(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_ge(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for >= instead of <.impl StructuralPartialEq for NonZeroCharInner
impl TrivialClone for NonZeroCharInner