#[repr(transparent)]pub struct NonZeroI8Inner(i8 is (..=0 | 1..=));🔬This is a nightly-only experimental API. (
temporary_niche_types)Tuple Fields
0: i8 is (..=0 | 1..=)🔬This is a nightly-only experimental API. (
temporary_niche_types)Implementations
Sourceimpl NonZeroI8Inner
impl NonZeroI8Inner
pub const fn new(val: i8) -> Option<Self>
🔬This is a nightly-only experimental API. (
temporary_niche_types)Sourcepub const unsafe fn new_unchecked(val: i8) -> Self
🔬This is a nightly-only experimental API. (temporary_niche_types)
pub const unsafe fn new_unchecked(val: i8) -> Self
temporary_niche_types)Constructs an instance of this type from the underlying integer primitive without checking whether its valid.
Safety
Immediate language UB if val is not within the valid range for this
type, as it violates the validity invariant.
pub const fn as_inner(self) -> i8
🔬This is a nightly-only experimental API. (
temporary_niche_types)Trait Implementations
Sourceimpl Clone for NonZeroI8Inner
impl Clone for NonZeroI8Inner
Sourcefn clone(&self) -> NonZeroI8Inner
fn clone(&self) -> NonZeroI8Inner
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)where
Self:,
fn clone_from(&mut self, source: &Self)where
Self:,
Performs copy-assignment from
source. Read moreimpl Copy for NonZeroI8Inner
Sourceimpl Debug for NonZeroI8Inner
impl Debug for NonZeroI8Inner
Sourceimpl Eq for NonZeroI8Inner
impl Eq for NonZeroI8Inner
1.0.0 (const: unstable) · Source#[doc(hidden)]fn assert_receiver_is_total_eq(&self)
#[doc(hidden)]fn assert_receiver_is_total_eq(&self)
👎Deprecated since 1.95.0:
implementation detail of #[derive(Eq)]
Source#[doc(hidden)]fn assert_fields_are_eq(&self)
#[doc(hidden)]fn assert_fields_are_eq(&self)
🔬This is a nightly-only experimental API. (
derive_eq_internals)Sourceimpl Hash for NonZeroI8Inner
impl Hash for NonZeroI8Inner
Sourceimpl Ord for NonZeroI8Inner
impl Ord for NonZeroI8Inner
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NonZeroI8Inner
impl PartialEq for NonZeroI8Inner
Sourceimpl PartialOrd for NonZeroI8Inner
impl PartialOrd for NonZeroI8Inner
Sourcefn partial_cmp(&self, other: &Self) -> Option<Ordering>
fn partial_cmp(&self, other: &Self) -> Option<Ordering>
Source#[doc(hidden)]fn __chaining_lt(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_lt(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)If
self == other, returns ControlFlow::Continue(()).
Otherwise, returns ControlFlow::Break(self < other). Read moreSource#[doc(hidden)]fn __chaining_le(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_le(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for <= instead of <.Source#[doc(hidden)]fn __chaining_gt(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_gt(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for > instead of <.Source#[doc(hidden)]fn __chaining_ge(&self, other: &Rhs) -> ControlFlow<bool>
#[doc(hidden)]fn __chaining_ge(&self, other: &Rhs) -> ControlFlow<bool>
🔬This is a nightly-only experimental API. (
partial_ord_chaining_methods)Same as
__chaining_lt, but for >= instead of <.impl StructuralPartialEq for NonZeroI8Inner
impl TrivialClone for NonZeroI8Inner