U64NotAllOnes

Struct U64NotAllOnes 

#[repr(transparent)]
pub struct U64NotAllOnes(u64 is 0..=u64::MAX);
🔬This is a nightly-only experimental API. (temporary_niche_types)

Tuple Fields

0: u64 is 0..=u64::MAX
🔬This is a nightly-only experimental API. (temporary_niche_types)

Implementations

Source

impl U64NotAllOnes

pub const fn new(val: u64) -> Option<Self>

🔬This is a nightly-only experimental API. (temporary_niche_types)
pub const unsafe fn new_unchecked(val: u64) -> Self

🔬This is a nightly-only experimental API. (temporary_niche_types)

Constructs an instance of this type from the underlying integer primitive without checking whether its valid.

Safety

Immediate language UB if val is not within the valid range for this type, as it violates the validity invariant.

pub const fn as_inner(self) -> u64

🔬This is a nightly-only experimental API. (temporary_niche_types)